@@ -36,7 +36,7 @@
     <message>
         <location filename="../maindialog.ui" line="122"/>
         <source>Color of shadow</source>
-        <translation>Árnyékszín</translation>
+        <translation>Árnyék színe</translation>
     </message>
     <message>
         <location filename="../maindialog.ui" line="57"/>
@@ -46,7 +46,7 @@
     <message>
         <location filename="../maindialog.ui" line="60"/>
         <source>Zero the part of the shadow&apos;s mask behind the window</source>
-        <translation>Ablakmögötti árnyékmaszk lekapcsolása</translation>
+        <translation>Ablak mögötti árnyékmaszk lekapcsolása</translation>
     </message>
     <message>
         <location filename="../maindialog.ui" line="50"/>
@@ -56,7 +56,7 @@
     <message>
         <location filename="../maindialog.ui" line="43"/>
         <source>Avoid drawing shadows on dock/panel windows</source>
-        <translation>Dock/Panel ablak árnyéktalan</translation>
+        <translation>Dokk/Panel árnyéktalan</translation>
     </message>
     <message>
         <location filename="../maindialog.ui" line="36"/>
@@ -71,7 +71,7 @@
     <message>
         <location filename="../maindialog.ui" line="143"/>
         <source>Crop shadows of maximized windows from extended displays</source>
-        <translation type="unfinished"></translation>
+        <translation>A maximalizált ablakok árnyékának kivágása a kibővített kijelzőkről</translation>
     </message>
     <message>
         <location filename="../maindialog.ui" line="151"/>
@@ -91,7 +91,7 @@
     <message>
         <location filename="../maindialog.ui" line="174"/>
         <source>Default opacity for active windows</source>
-        <translation>Aktív ablak alap áttetszősége</translation>
+        <translation>Aktív ablak alapértelmezett áttetszősége</translation>
     </message>
     <message>
         <location filename="../maindialog.ui" line="181"/>
@@ -113,7 +113,7 @@
     <message>
         <location filename="../maindialog.ui" line="203"/>
         <source>Do not let dimness adjust based on window opacity</source>
-        <translation>Elsötétítés az ablak áttetszőségétől független</translation>
+        <translation>Elsötétítés az ablak áttetszőségétől függetlenül</translation>
     </message>
     <message>
         <location filename="../maindialog.ui" line="210"/>
@@ -123,7 +123,7 @@
     <message>
         <location filename="../maindialog.ui" line="217"/>
         <source>Blur background of opaque windows with transparent frames as well</source>
-        <translation>Áttetsző keretű opak ablakok háttere is elmosott</translation>
+        <translation>Áttetsző keretű átlátszatlan ablakok háttere is elmosott</translation>
     </message>
     <message>
         <location filename="../maindialog.ui" line="224"/>
@@ -158,7 +158,7 @@
     <message>
         <location filename="../maindialog.ui" line="326"/>
         <source>Avoid fade windows in/out when opening/closing</source>
-        <translation>Ablaknyitásnál, zárásnál nincs áttűnési hatás</translation>
+        <translation>Ablaknyitásnál, zárásnál nincs áttűnés</translation>
     </message>
     <message>
         <location filename="../maindialog.ui" line="369"/>
@@ -168,27 +168,27 @@
     <message>
         <location filename="../maindialog.ui" line="381"/>
         <source>Rendering backend</source>
-        <translation type="unfinished"></translation>
+        <translation>Képkészítő API</translation>
     </message>
     <message>
         <location filename="../maindialog.ui" line="393"/>
         <source>X Render</source>
-        <translation type="unfinished"></translation>
+        <translation>X Render</translation>
     </message>
     <message>
         <location filename="../maindialog.ui" line="400"/>
         <source>GLX (OpenGL)</source>
-        <translation type="unfinished"></translation>
+        <translation>GLX (OpenGL)</translation>
     </message>
     <message>
         <location filename="../maindialog.ui" line="416"/>
         <source>About</source>
-        <translation>Rólunk</translation>
+        <translation>Névjegy</translation>
     </message>
     <message>
         <location filename="../maindialog.cpp" line="209"/>
         <source>About ComptonConf</source>
-        <translation>A ComptonConf</translation>
+        <translation>A ComptonConf névjegye</translation>
     </message>
     <message>
         <location filename="../maindialog.cpp" line="210"/>
@@ -199,7 +199,7 @@ Author: Hong Jen Yee (PCMan) &lt;pcman.tw@gmail.com&gt;</source>
         <translation>ComptonConf - Compton beállító eszköz
 
 Copyright (C) 2013
-Autor: Hong Jen Yee (PCMan) &lt;pcman.tw@gmail.com&gt;</translation>
+Szerző: Hong Jen Yee (PCMan) &lt;pcman.tw@gmail.com&gt;</translation>
     </message>
 </context>
 </TS>
