@@ -21,12 +21,12 @@
     <message>
         <location filename="../maindialog.ui" line="77"/>
         <source>The left offset for shadows</source>
-        <translation>影の左のオフセット</translation>
+        <translation>影の左オフセット</translation>
     </message>
     <message>
         <location filename="../maindialog.ui" line="91"/>
         <source>The top offset for shadows</source>
-        <translation>影の上のオフセット</translation>
+        <translation>影の上オフセット</translation>
     </message>
     <message>
         <location filename="../maindialog.ui" line="105"/>
@@ -41,17 +41,17 @@
     <message>
         <location filename="../maindialog.ui" line="57"/>
         <source>Fix some weirdness with ARGB windows</source>
-        <translation>ARGBウインドウの異常を直す</translation>
+        <translation>ARGB ウィンドウの異常を修正します</translation>
     </message>
     <message>
         <location filename="../maindialog.ui" line="60"/>
         <source>Zero the part of the shadow&apos;s mask behind the window</source>
-        <translation>ウインドウ背後の影のマスクをゼロにする</translation>
+        <translation>ウィンドウ背後の影のマスクを 0 にする</translation>
     </message>
     <message>
         <location filename="../maindialog.ui" line="50"/>
         <source>Don&apos;t draw shadows on DND windows</source>
-        <translation>ドラッグアンドドロップのオブジェクトの影を描画しない</translation>
+        <translation>ドラッグアンドドロップのウィンドウに影を描画しない</translation>
     </message>
     <message>
         <location filename="../maindialog.ui" line="43"/>
@@ -61,17 +61,17 @@
     <message>
         <location filename="../maindialog.ui" line="36"/>
         <source>Enable client-side shadows on windows</source>
-        <translation>ウインドウのクライアント側の影を有効にする</translation>
+        <translation>ウィンドウのクライアント側の影を有効にする</translation>
     </message>
     <message>
         <location filename="../maindialog.ui" line="136"/>
         <source>Avoid drawing shadow on all shaped windows</source>
-        <translation>すべて整形済のウインドウに影を描画しない</translation>
+        <translation>すべて整形済のウィンドウに影を描画しない</translation>
     </message>
     <message>
         <location filename="../maindialog.ui" line="143"/>
         <source>Crop shadows of maximized windows from extended displays</source>
-        <translation type="unfinished"></translation>
+        <translation>拡張ディスプレイから最大化されたウィンドウの影を切り取る</translation>
     </message>
     <message>
         <location filename="../maindialog.ui" line="151"/>
@@ -86,12 +86,12 @@
     <message>
         <location filename="../maindialog.ui" line="167"/>
         <source>Default opacity of inactive windows</source>
-        <translation>非アクティブウインドウの透明度</translation>
+        <translation>非アクティブウィンドウの透明度</translation>
     </message>
     <message>
         <location filename="../maindialog.ui" line="174"/>
         <source>Default opacity for active windows</source>
-        <translation>アクティブウインドウの透明度</translation>
+        <translation>アクティブウィンドウの透明度</translation>
     </message>
     <message>
         <location filename="../maindialog.ui" line="181"/>
@@ -102,32 +102,33 @@
         <location filename="../maindialog.ui" line="188"/>
         <source>XRender backend: Step size for alpha pictures
 (Increasing it may result in less X resource usage)</source>
-        <translation>XRenderバックエンド: アルファピクチャーのステップサイズ（増やすと、Xのリソース消費量が減ります）</translation>
+        <translation>XRender バックエンド: アルファピクチャーのステップサイズ
+(増やすと X のリソース使用量が減るでしょう)</translation>
     </message>
     <message>
         <location filename="../maindialog.ui" line="196"/>
         <source>Dim inactive windows</source>
-        <translation>非アクティブウインドウを暗くする</translation>
+        <translation>非アクティブウィンドウを暗くする</translation>
     </message>
     <message>
         <location filename="../maindialog.ui" line="203"/>
         <source>Do not let dimness adjust based on window opacity</source>
-        <translation>ウインドウの透明度にあわせた暗さの調節をしない</translation>
+        <translation>ウィンドウの透明度に合わせた暗さの調節をしない</translation>
     </message>
     <message>
         <location filename="../maindialog.ui" line="210"/>
         <source>Blur background of transparent windows</source>
-        <translation>透明化ウインドウの背後をぼかす</translation>
+        <translation>透明化ウィンドウの背後をぼかす</translation>
     </message>
     <message>
         <location filename="../maindialog.ui" line="217"/>
         <source>Blur background of opaque windows with transparent frames as well</source>
-        <translation>透明化フレームを伴う不透明ウインドウの背後をぼかす</translation>
+        <translation>透明化フレームを伴う不透明ウィンドウの背後をぼかす</translation>
     </message>
     <message>
         <location filename="../maindialog.ui" line="224"/>
         <source>Do not let blur radius adjust based on window opacity</source>
-        <translation>ウインドウの透明度にあわせたぼかし半径の調節をしない</translation>
+        <translation>ウィンドウの透明度に合わせたぼかし半径の調節をしない</translation>
     </message>
     <message>
         <location filename="../maindialog.ui" line="292"/>
@@ -137,7 +138,7 @@
     <message>
         <location filename="../maindialog.ui" line="298"/>
         <source>Fade windows during opacity changes</source>
-        <translation>透明度の変化中にウインドウをフェードする</translation>
+        <translation>透明度の変化中にウィンドウをフェードする</translation>
     </message>
     <message>
         <location filename="../maindialog.ui" line="305"/>
@@ -157,7 +158,7 @@
     <message>
         <location filename="../maindialog.ui" line="326"/>
         <source>Avoid fade windows in/out when opening/closing</source>
-        <translation>ウインドウの開閉時にフェードしない</translation>
+        <translation>ウィンドウの開閉時にフェードしない</translation>
     </message>
     <message>
         <location filename="../maindialog.ui" line="369"/>
@@ -167,7 +168,7 @@
     <message>
         <location filename="../maindialog.ui" line="381"/>
         <source>Rendering backend</source>
-        <translation type="unfinished"></translation>
+        <translation>バックエンドのレンダリング</translation>
     </message>
     <message>
         <location filename="../maindialog.ui" line="393"/>
@@ -182,12 +183,12 @@
     <message>
         <location filename="../maindialog.ui" line="416"/>
         <source>About</source>
-        <translation>情報</translation>
+        <translation>このアプリケーションについて</translation>
     </message>
     <message>
         <location filename="../maindialog.cpp" line="209"/>
         <source>About ComptonConf</source>
-        <translation>ComptonConfについて</translation>
+        <translation>ComptonConf について</translation>
     </message>
     <message>
         <location filename="../maindialog.cpp" line="210"/>
